.. _preprocessor_functions:

Preprocessor functions
======================

By default, preprocessor functions are applied in the order in which they are listed here.

.. automodule:: esmvalcore.preprocessor
